BaseSegmentAnomalyDetector
===================================================================

.. currentmodule:: skchange.anomaly_detectors

.. autoclass:: BaseSegmentAnomalyDetector

.. include:: skchange.anomaly_detectors.BaseSegmentAnomalyDetector.examples

.. raw:: html

    <div class="clearer"></div>